@@ -1,19 +1,20 @@
 ####################################################################################
-####                     Deep Time Series Early Alpha  0.1.1                    ####
-####                           Python 3 Version                                 ####
-####                    Conceived and Developed by Kevin Chen                   ####
-####                        All Rights Reserved                                 ####
+####                     Auto Time Series Early Alpha v0.1.5                    ####
+####                              Python 3 Version                              ####
+####                    Conceived and Created by Ram Seshadri                   ####
+####                       Further Developed by Kevin Chen                      ####
+####                            All Rights Reserved                             ####
 ####################################################################################
 
 from IPython.display import display, HTML
-import pandas as pd
 import numpy as np
+import pandas as pd
 from datetime import datetime
 import warnings
 warnings.filterwarnings("ignore")
 import seaborn as sns
 import matplotlib.pyplot as plt
-get_ipython().magic('matplotlib inline')
+# get_ipython().magic('matplotlib inline')
 sns.set(style="white", color_codes=True)
 import copy
 import ipdb
@@ -47,10 +48,10 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
                   conf_int=0.95, model_type="stats", verbose=0):
     """
     ####################################################################################
-    ####                              Auto Time Series                              ####
-    ####                               Version 0.1.4                                ####
-    ####                    Conceived and Developed by Kevin Chen                   ####
-    ####                       Original Credit to Ram Seshadri                      ####
+    ####                               Auto Time Series                             ####
+    ####                                Version 0.1.5                               ####
+    ####            Conceived and Created Auto_TimeSeries by Ram Seshadri           ####
+    ####                      Further Developed by Kevin Chen                       ####
     ####                            All Rights Reserved                             ####
     ####################################################################################
     ##################################################################################################
@@ -596,13 +597,13 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
                     print(colorful.BOLD + '\nRunning Machine Learning Models...' + colorful.END)
                     print('    Shifting %d predictors by lag=%d to align prior predictor with current target...'
                                 % (len(preds), lag))
-                    # ipdb.set_trace()
-                    dfxs, target, preds = convert_timeseries_dataframe_to_supervised(ts_df[preds+[target]],
-                                            preds+[target], target, n_in=lag, n_out=0, dropT=False)
-                    train = dfxs[:-forecast_period]
-                    test = dfxs[-forecast_period:]
-                    best = run_ensemble_model(train[preds], train[target], 'TimeSeries',
-                                              score_type, verbose)
+                    # dfxs, target, preds = convert_timeseries_dataframe_to_supervised(ts_df[preds+[target]],
+                    #                         preds+[target], target, n_in=lag, n_out=0, dropT=False)
+                    # train = dfxs[:-forecast_period]
+                    # test = dfxs[-forecast_period:]
+                    # best = run_ensemble_model(train[preds], train[target], 'TimeSeries',
+                    #                           score_type, verbose)
+                    best = run_ensemble_model(X, y, 'TimeSeries', score_type, verbose)
                     bestmodel = best[0]
                     model_dict[name]['model'] = bestmodel
                     ### Certain models dont have random state => so dont do this for all since it will error
@@ -619,13 +620,15 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
                     plt.ylabel('Predicted')
                     plt.show()
                     ############ Draw a plot of the Time Series data ######
-                    time_series_plot(dfxs[target], chart_time=timeinterval)
+                    # time_series_plot(dfxs[target], chart_time=time_interval)
                 else:
                     print(colorful.BOLD + '\nNo predictors available. Skipping Machine Learning model...' + colorful.END)
                     score_val = np.inf
             except:
                 print('    For ML model, evaluation score is not available.')
                 score_val = np.inf
+                rmse = np.inf
+                norm_rmse = np.inf
         ################################################################
         if score_type == 'rmse':
             score_val = rmse
@@ -640,7 +643,7 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
     print("STEP 10) Model Search IV (DL Models)")
     print("-------------------------------------------------------------------\n")
 
-    if model_type.lower() in ['dl', 'dnn', 'deep', 'all']:
+    if model_type.lower() in ['ml', 'dnn', 'deep', 'all']:
 
         if len(tf.config.list_physical_devices('GPU')) > 0:
             print("GPU is enabled.")
@@ -648,8 +651,8 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
             print("Running on CPU as GPU is not enabled.")
 
         model_dict = run_deep_model(model_dict, X_train, y_train, X_val, y_val,
-                                 n_input, n_output, n_units, d_rate, n_epoch,
-                                 n_batch, score_type)
+                                    n_input, n_output, n_units, d_rate, n_epoch,
+                                    n_batch, score_type)
 
 
     print("\n\n-------------------------------------------------------------------")
