@@ -2,9 +2,9 @@
 """Specifies the version of the Deep Time-Series package."""
 
 __title__ = "autotime"
-__author__ = "Kevin R. Chen"
+__author__ = "Ram Seshadri and Kevin R. Chen"
 __description__ = "Automated ML-based predictive analytics framework for time-series data."
 __url__ = "https://github.com/Kevin-Chen0/auto-time-series.git"
-__version__ = "0.1.4.1"
+__version__ = "0.1.5"
 __license__ = "Apache License 2.0"
-__copyright__ = "2020 Kevin R. Chen"
+__copyright__ = "2020 Ram Seshadri and Kevin R. Chen"
\ No newline at end of file
