@@ -1,5 +1,7 @@
 import numpy as np
 import pandas as pd
+from random import randint
+from tscv import GapKFold
 # imported ML models from scikit-learn
 from sklearn.model_selection import ShuffleSplit, StratifiedShuffleSplit, \
                                     TimeSeriesSplit, cross_val_score
@@ -64,6 +66,9 @@ def run_ensemble_model(X, Y, modeltype='Regression', scoring='', verbose=0):
         #### This section is for Time Series Models only ####
         if scoring == '':
             scoring = 'neg_mean_squared_error'
+        # gap2 = randint(0, int(0.001*len(X)))
+        # n_split = FOLDS
+        # tscv = GapKFold(n_splits=FOLDS, gap_before=gap2, gap_after=gap2)
         tscv = TimeSeriesSplit(n_splits=FOLDS)
         scoring = 'neg_mean_squared_error'
         model5 = SVR(C=0.1, kernel='rbf', degree=2)
