@@ -1,6 +1,8 @@
 import numpy as np
 import pandas as pd
 from random import randint
+import datetime
+import pytz
 import copy
 import ipdb
 from sklearn.preprocessing import MinMaxScaler, StandardScaler, power_transform
@@ -36,7 +38,8 @@ def load_ts_data(data, ts_column, sep=','):
     return df
 
 
-def clean_ts_data(df, target, as_freq='H', allow_neg=True, fill='linear', type='reg'):
+def clean_ts_data(df, target, timezone=None, as_freq='H', allow_neg=True,
+                  fill='linear', type='reg'):
 
     dtc = df.copy()
     # 1) Sort DateTimeIndex is asc order just in case it hasn't been done
@@ -49,8 +52,12 @@ def clean_ts_data(df, target, as_freq='H', allow_neg=True, fill='linear', type='
     else:
         print("    - Checked that there are no duplicate times.")
     # 3) Add freq to time-series col or index if it doesn't exist
+    tz_offset = 0
+    if timezone is not None:
+        tz = datetime.datetime.now(pytz.timezone(timezone))
+        tz_offset += tz.utcoffset().total_seconds()/60/60
     if not isinstance(dtc.index, pd.DatetimeIndex):
-        dtc.index = pd.DatetimeIndex(dtc.index)
+        dtc.index = pd.to_datetime(dtc.index, utc=True)
     if dtc.index.freq is None:
         f_idx = pd.date_range(start=dtc.index.min(), end=dtc.index.max(), freq=as_freq) \
                   .tz_localize(None)
@@ -60,6 +67,9 @@ def clean_ts_data(df, target, as_freq='H', allow_neg=True, fill='linear', type='
         else:
             dtc = dtc.reindex(f_idx)
         print(f"    - Added freq '{as_freq}' to DateTimeIndex.")
+    if tz_offset != 0:
+        dtc.index = dtc.index.shift(tz_offset)
+        print("    - Removed timezone by converting to UTC and then reshifting back. ")
     # 4) Convert target col type to float is not already and removing any puncuations
     if type == 'reg' and dtc[target].dtype.kind != 'f':
         dtc[target] = dtc[target].str.replace('[^\d\.]', '').astype(np.float32)
